@@ -1,7 +1,7 @@
 package Getopt::Long::Dump;
 
 our $DATE = '2016-10-21'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 use 5.010;
 use strict;
@@ -91,7 +91,9 @@ sub dump_getopt_long_script {
                         "stdout=<<$stdout>>, stderr=<<$stderr>>"];
     }
 
-    [200, "OK", $spec];
+    [200, "OK", $spec, {
+        'func.detect_res' => $detres,
+    }];
 }
 
 1;
@@ -109,7 +111,7 @@ Getopt::Long::Dump - Run a Getopt::Long-based script but only to dump the spec
 
 =head1 VERSION
 
-This document describes version 0.06 of Getopt::Long::Dump (from Perl distribution Getopt-Long-Dump), released on 2016-10-21.
+This document describes version 0.07 of Getopt::Long::Dump (from Perl distribution Getopt-Long-Dump), released on 2016-10-21.
 
 =head1 FUNCTIONS
 
